@@ -15,13 +15,15 @@ class S3SaveHandler(AbstractSaveHandler):
     def __init__(self):
         super().__init__()
         logger.info(f"Connecting to AWS S3 Bucket {settings.bucket}")
-        sess = Session(settings.access_key, settings.secret_access_key)
-        self.s3 = sess.s3(settings.bucket)
-        if settings.get("proxy", None):
+        proxy = settings.get("proxy", None)
+        if proxy:
             logger.info(f"Using proxy for S3 connection. Proxy: {settings.proxy}")
-            self.s3.client = sess.get_session().client(
-                "s3", config=botocore.client.Config(proxies=settings.proxy)
-            )
+        sess = Session(
+            settings.access_key,
+            settings.secret_access_key,
+            config=botocore.client.Config(proxies=proxy, max_pool_connections=1000),
+        )
+        self.s3 = sess.s3(settings.bucket)
 
     def write_file(self, dirname, filename, obj):
         key = dirname + filename
